<?php
namespace Inti\Wp\Authentication;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use WP_User;
use Zend\Diactoros\Response\EmptyResponse;
use Zend\Expressive\Authentication\AuthenticationInterface;
use Zend\Expressive\Authentication\DefaultUser;
use Zend\Expressive\Authentication\UserInterface;

/**
 * Class WordPressAuthentication
 *
 * @package Inti\Wp\Authentication
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WordPressAuthentication implements AuthenticationInterface
{
    /**
     * Authenticate the PSR-7 request and return a valid user
     * or null if not authenticated
     *
     * @param ServerRequestInterface $request
     * @return UserInterface|null
     */
    public function authenticate(ServerRequestInterface $request): ?UserInterface
    {
        $user = wp_get_current_user();

        if ($user instanceof WP_User && $user->ID > 0) {
            $userMeta = get_user_meta($user->ID);
            return new DefaultUser($user->ID, $user->roles, $userMeta);
        }

        return null;
    }

    /**
     * Generate the unauthorized response
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function unauthorizedResponse(ServerRequestInterface $request): ResponseInterface
    {
        return new EmptyResponse(401);
    }
}