<?php
namespace Inti\Wp;

use Zend\Expressive\Authentication\AuthenticationInterface;
use Zend\Expressive\Authentication\AuthenticationMiddleware;

/**
 * Class ConfigProvider
 *
 * @package Inti\Wp
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class ConfigProvider
{
    /**
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'dependencies' => $this->getDependencies(),
            'middleware_pipeline' => $this->getPipelineConfig(),
        ];
    }

    /**
     * @return array
     */
    public function getDependencies(): array
    {
        return [
            'aliases' => [
                AuthenticationInterface::class => Authentication\WordPressAuthentication::class,
            ],

            'factories' => [
                AuthenticationMiddleware::class => Authentication\AuthenticationMiddlewareFactory::class,
                WordPressHandler::class => WordPressHandlerFactory::class,
                WordPressMiddleware::class => WordPressMiddlewareFactory::class,
                Plugin\PluginLoader::class => Plugin\PluginLoaderFactory::class,
            ],
        ];
    }

    /**
     * @return array
     */
    public function getPipelineConfig(): array
    {
        return [[
            'middleware' => WordPressHandler::class,
            'priority' => -10,
        ]];
    }
}