<?php
namespace Inti\Wp;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class WordPressMiddleware
 *
 * @package Inti\Wp
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp
 */
final class WordPressMiddleware implements MiddlewareInterface
{
    /**
     * Process an incoming server request.
     *
     * Processes an incoming server request in order to produce a response.
     * If unable to produce the response itself, it may delegate to the provided
     * request handler to do so.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $this->declareConstants($request);

        /** @noinspection PhpUnusedLocalVariableInspection */
        $table_prefix = 'wp_';

        /** @noinspection PhpUnusedLocalVariableInspection */
        global $wc_cpdf, $extensions_uri, $nav_elements, $extensions_url,
               $revSliderVersion, $timeline_express_base;

        /** @noinspection PhpIncludeInspection */
        require ABSPATH . 'wp-settings.php';

        wp();

        return $handler->handle($request);
    }

    /**
     * @param ServerRequestInterface $request
     */
    public function declareConstants(ServerRequestInterface $request): void
    {
        $config = $request->getAttribute('config');

        define('ABSPATH', realpath('public/wp') . '/');

        define('WP_DEBUG', $config['wp']['debug'] ?? false);
        define('WP_DEBUG_DISPLAY', WP_DEBUG);

        $baseUrl = (string) $request->getUri()->withPath('/')->withQuery('');

        define('WP_HOME', rtrim($baseUrl, '/'));
        define('WP_SITEURL', WP_HOME . '/wp');

        define('WP_CONTENT_DIR', dirname(ABSPATH) . '/wp-content');
        define('WP_CONTENT_URL', WP_HOME . '/wp-content');

        define('DB_HOST', $config['db']['host'] ?? 'localhost');
        define('DB_USER', $config['db']['user'] ?? '');
        define('DB_PASSWORD', $config['db']['password'] ?? '');
        define('DB_NAME', $config['db']['dbname'] ?? '');
        define('DB_CHARSET', $config['db']['charset'] ?? 'utf8mb4');
        define('DB_COLLATE', $config['db']['collate'] ?? 'utf8mb4');

        define('WP_DEFAULT_THEME', 'flatsome');
        define('WP_DISABLE_FATAL_ERROR_HANDLER', true);

        /** @noinspection PhpUnusedLocalVariableInspection */
        global $table_prefix;
        $table_prefix = 'wp_';
    }
}